History
=======

0.0.2 (2023-10-02)
--------------------
* Initial unadvertised prerelease with basic read-only patching working X-platform;

0.0.1 (2023-03-25)
--------------------
* Initial package squat release of superduperreload;
